@@ -3,7 +3,7 @@ from __init__ import Overwatch
 def main():
     overwatch = Overwatch(battletag="Okush#11324")
 
-    print(overwatch(hero="junkrat", filter="hero specific"))
+    print(overwatch.playtime)
  
     # print(overwatch(hero="mei", filter="hero specific"))
     # print(overwatch(hero="dva", filter="combat"))
